;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "apheleia" "4.4.3"
  "Reformat buffer stably."
  '((emacs "27"))
  :url "https://github.com/radian-software/apheleia"
  :commit "2bc2bb4cc2caad111e6f2f1b9daf20ec388101ff"
  :revdesc "2bc2bb4cc2ca"
  :keywords '("tools")
  :authors '(("Radian LLC" . "contact+apheleia@radian.codes"))
  :maintainers '(("Radian LLC" . "contact+apheleia@radian.codes")))
